.. borinud documentation master file, created by
   sphinx-quickstart on Thu Jul 24 08:13:13 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to borinud's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2

   README
   CHANGES
   TODO
   CONTRIBUTORS


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

